summaryrefslogtreecommitdiffstats
path: root/pkg/i18n/i18n.go
diff options
context:
space:
mode:
Diffstat (limited to 'pkg/i18n/i18n.go')
-rw-r--r--pkg/i18n/i18n.go83
1 files changed, 9 insertions, 74 deletions
diff --git a/pkg/i18n/i18n.go b/pkg/i18n/i18n.go
index 346b370fa..c743218f8 100644
--- a/pkg/i18n/i18n.go
+++ b/pkg/i18n/i18n.go
@@ -1,4 +1,4 @@
-package main
+package lang
import (
"github.com/BurntSushi/toml"
@@ -11,76 +11,11 @@ func getlocalizer() *i18n.Localizer {
// TODO: currently the system language issn't detected
// I'm not sure how to detect it
- var i18nObject = &i18n.Bundle{DefaultLanguage: language.English}
+ var i18nObject = &i18n.Bundle{DefaultLanguage: language.Dutch}
i18nObject.RegisterUnmarshalFunc("toml", toml.Unmarshal)
- // To add more translations do:
- // AddMessages(tag language.Tag, messages ...*Message)
- // https://godoc.org/github.com/nicksnyder/go-i18n/v2/i18n#Bundle.AddMessages
-
- // Dutch translation for some words
- i18nObject.AddMessages(language.Dutch,
- &i18n.Message{
- ID: "FilesTitle",
- Other: "Bestanden",
- }, &i18n.Message{
- ID: "BranchesTitle",
- Other: "Branches",
- }, &i18n.Message{
- ID: "CommitsTitle",
- Other: "Commits",
- }, &i18n.Message{
- ID: "StashTitle",
- Other: "Stash",
- }, &i18n.Message{
- ID: "CommitMessage",
- Other: "Commit Bericht",
- }, &i18n.Message{
- ID: "CommitChanges",
- Other: "Commit Veranderingen",
- }, &i18n.Message{
- ID: "StatusTitle",
- Other: "Status",
- }, &i18n.Message{
- ID: "navigate",
- Other: "navigeer",
- }, &i18n.Message{
- ID: "stashFiles",
- Other: "stash-bestanden",
- }, &i18n.Message{
- ID: "open",
- Other: "open",
- }, &i18n.Message{
- ID: "ignore",
- Other: "negeren",
- }, &i18n.Message{
- ID: "delete",
- Other: "verwijderen",
- }, &i18n.Message{
- ID: "toggleStaged",
- Other: "toggle staged",
- }, &i18n.Message{
- ID: "refresh",
- Other: "verversen",
- }, &i18n.Message{
- ID: "addPatch",
- Other: "verandering toevoegen",
- }, &i18n.Message{
- ID: "edit",
- Other: "veranderen",
- }, &i18n.Message{
- ID: "scroll",
- Other: "scroll",
- }, &i18n.Message{
- ID: "abortMerge",
- Other: "samenvoegen afbreken",
- }, &i18n.Message{
- ID: "resolveMergeConflicts",
- Other: "verhelp samenvoegen fouten",
- },
-
- //
- )
+ // add translation file(s)
+ i18nObject = addDutch(i18nObject)
return i18n.NewLocalizer(i18nObject)
}
@@ -88,18 +23,18 @@ func getlocalizer() *i18n.Localizer {
// setup the localizer for later use
var localizer = getlocalizer()
-// MustLocalize handels the translations
+// Localize handels the translations
// expects i18n.LocalizeConfig as input: https://godoc.org/github.com/nicksnyder/go-i18n/v2/i18n#Localizer.MustLocalize
// output: translated string
-func MustLocalize(config *i18n.LocalizeConfig) string {
+func Localize(config *i18n.LocalizeConfig) string {
return localizer.MustLocalize(config)
}
// ShortLocalize is for 1 line localizations
// ID: The id that is used in the .toml translation files
// Other: the default message it needs to return if there is no translation found or the system is english
-func ShortLocalize(ID string, Other string) string {
- return MustLocalize(&i18n.LocalizeConfig{
+func SLocalize(ID string, Other string) string {
+ return Localize(&i18n.LocalizeConfig{
DefaultMessage: &i18n.Message{
ID: ID,
Other: Other,
@@ -88,18 +23,18 @@ func getlocalizer() *i18n.Localizer {
return localizer.MustLocalize(config)
}
-// ShortLocalize is for 1 line localizations
+// SLocalize (short localize) is for 1 line localizations
// ID: The id that is used in the .toml translation files
// Other: the default message it needs to return if there is no translation found or the system is english